﻿namespace Tests;
using Models.Game;
using Models.Rules;

public class RulesTests
{
    [Fact]
    public void IsCellEmpty_ReturnsTrue_WhenCellIsNull()
    {
        Rules rules = new Rules();
        Assert.True(rules.IsCellEmpty(null));
    }
    
    [Fact]
    public void IsCellEmpty_ReturnsTrue_WhenCellValueIsNull()
    {
        Rules rules = new Rules();
        Cell cell = new Cell(0, 0);
        Assert.True(rules.IsCellEmpty(cell));
    }
    
    [Fact]
    public void IsCellEmpty_ReturnsFalse_WhenCellValueIsNotNull()
    {
        Rules rules = new Rules();
        Cell cell = new Cell(0, 0);
        cell.Value = 1;
        Assert.False(rules.IsCellEmpty(cell));
    }
    
    [Fact]
    public void IsCellValid_ReturnsFalse_WhenCellIsNotEmptyAndHasAdjacentCells()
    {
        Rules rules = new Rules();
        Map map = new Map("background");
        Cell selectedCell = map.Boards[0];
        selectedCell.Value = 5;
        Assert.False(rules.IsCellValid(selectedCell, map.Boards));
    }
    
    [Fact]
    public void IsCellValid_ReturnsTrue_WhenCellIsEmptyAndHasAdjacentCells()
    {
        Rules rules = new Rules();
        Map map = new Map("background");
        Cell selectedCell = map.Boards[0];
        Assert.True(rules.IsCellValid(selectedCell, map.Boards));
    }
    
    [Fact]
    public void IsCellAdjacent_ReturnsFalse_WhenCellsAreNotAdjacent()
    {
        Rules rules = new Rules();
        Cell cell1 = new Cell(0, 0);
        Cell cell2 = new Cell(2, 2);
        Assert.False(rules.IsCellAdjacent(cell1, cell2));
    }
    
    [Fact]
    public void IsCellAdjacent_ReturnsTrue_WhenCellsAreSideBySide()
    {
        Rules rules = new Rules();
        Cell cell1 = new Cell(0, 0);
        Cell cell2 = new Cell(0, 1);
        Assert.True(rules.IsCellAdjacent(cell1, cell2));
    }
    
    [Fact]
    public void IsCellAdjacent_ReturnsTrue_WhenCellsAreDiagonal()
    {
        Rules rules = new Rules();
        Cell cell1 = new Cell(0, 0);
        Cell cell2 = new Cell(1, 1);
        Assert.True(rules.IsCellAdjacent(cell1, cell2));
    }
}